==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStacksTemplateLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Entity representing the reference to the template.
 * @property contentVersion If included, must match the ContentVersion in the template.
 * @property id The resource id of a Template Spec. Use either the id or uri property, but not both.
 * @property queryString The query string (for example, a SAS token) to be used with the templateLink URI.
 * @property relativePath The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
 * @property uri The URI of the template to deploy. Use either the uri or id property, but not both.
 */
public data class DeploymentStacksTemplateLinkArgs(
    public val contentVersion: Output<String>? = null,
    public val id: Output<String>? = null,
    public val queryString: Output<String>? = null,
    public val relativePath: Output<String>? = null,
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs.builder()
            .contentVersion(contentVersion?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .queryString(queryString?.applyValue({ args0 -> args0 }))
            .relativePath(relativePath?.applyValue({ args0 -> args0 }))
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentStacksTemplateLinkArgs].
 */
@PulumiTagMarker
public class DeploymentStacksTemplateLinkArgsBuilder internal constructor() {
    private var contentVersion: Output<String>? = null

    private var id: Output<String>? = null

    private var queryString: Output<String>? = null

    private var relativePath: Output<String>? = null

    private var uri: Output<String>? = null

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("oradfogsdblnglux")
    public suspend fun contentVersion(`value`: Output<String>) {
        this.contentVersion = value
    }

    /**
     * @param value The resource id of a Template Spec. Use either the id or uri property, but not both.
     */
    @JvmName("kltsmtqrldlggsem")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The query string (for example, a SAS token) to be used with the templateLink URI.
     */
    @JvmName("lrauvddcqvmnkqll")
    public suspend fun queryString(`value`: Output<String>) {
        this.queryString = value
    }

    /**
     * @param value The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
     */
    @JvmName("qooqhaqevlvvyukq")
    public suspend fun relativePath(`value`: Output<String>) {
        this.relativePath = value
    }

    /**
     * @param value The URI of the template to deploy. Use either the uri or id property, but not both.
     */
    @JvmName("sghyrwgxcaegixva")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("ljkwktameidstoet")
    public suspend fun contentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentVersion = mapped
    }

    /**
     * @param value The resource id of a Template Spec. Use either the id or uri property, but not both.
     */
    @JvmName("dptnihjsedrrnlct")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The query string (for example, a SAS token) to be used with the templateLink URI.
     */
    @JvmName("sfqhbdxkjdwviykk")
    public suspend fun queryString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryString = mapped
    }

    /**
     * @param value The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
     */
    @JvmName("icvtgqhlltvaoixs")
    public suspend fun relativePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relativePath = mapped
    }

    /**
     * @param value The URI of the template to deploy. Use either the uri or id property, but not both.
     */
    @JvmName("wfaoblxfudlndfey")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): DeploymentStacksTemplateLinkArgs = DeploymentStacksTemplateLinkArgs(
        contentVersion = contentVersion,
        id = id,
        queryString = queryString,
        relativePath = relativePath,
        uri = uri,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/DeploymentStacksTemplateLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Entity representing the reference to the template.
 * @property contentVersion If included, must match the ContentVersion in the template.
 * @property id The resource id of a Template Spec. Use either the id or uri property, but not both.
 * @property queryString The query string (for example, a SAS token) to be used with the templateLink URI.
 * @property relativePath The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
 * @property uri The URI of the template to deploy. Use either the uri or id property, but not both.
 */
public data class DeploymentStacksTemplateLinkArgs(
    public val contentVersion: Output<String>? = null,
    public val id: Output<String>? = null,
    public val queryString: Output<String>? = null,
    public val relativePath: Output<String>? = null,
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs =
        com.pulumi.azurenative.resources.inputs.DeploymentStacksTemplateLinkArgs.builder()
            .contentVersion(contentVersion?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .queryString(queryString?.applyValue({ args0 -> args0 }))
            .relativePath(relativePath?.applyValue({ args0 -> args0 }))
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentStacksTemplateLinkArgs].
 */
@PulumiTagMarker
public class DeploymentStacksTemplateLinkArgsBuilder internal constructor() {
    private var contentVersion: Output<String>? = null

    private var id: Output<String>? = null

    private var queryString: Output<String>? = null

    private var relativePath: Output<String>? = null

    private var uri: Output<String>? = null

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("gcdnequokjnpymds")
    public suspend fun contentVersion(`value`: Output<String>) {
        this.contentVersion = value
    }

    /**
     * @param value The resource id of a Template Spec. Use either the id or uri property, but not both.
     */
    @JvmName("lougfsuyhuxkhful")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The query string (for example, a SAS token) to be used with the templateLink URI.
     */
    @JvmName("gvdaogekmjdjxstt")
    public suspend fun queryString(`value`: Output<String>) {
        this.queryString = value
    }

    /**
     * @param value The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
     */
    @JvmName("dekufnokrjjlcamg")
    public suspend fun relativePath(`value`: Output<String>) {
        this.relativePath = value
    }

    /**
     * @param value The URI of the template to deploy. Use either the uri or id property, but not both.
     */
    @JvmName("devuhdomkfpytuow")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value If included, must match the ContentVersion in the template.
     */
    @JvmName("ywghcqpulnytwgvo")
    public suspend fun contentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentVersion = mapped
    }

    /**
     * @param value The resource id of a Template Spec. Use either the id or uri property, but not both.
     */
    @JvmName("dvucmcjbeukhqngk")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The query string (for example, a SAS token) to be used with the templateLink URI.
     */
    @JvmName("toxkflipwimubrgq")
    public suspend fun queryString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryString = mapped
    }

    /**
     * @param value The relativePath property can be used to deploy a linked template at a location relative to the parent. If the parent template was linked with a TemplateSpec, this will reference an artifact in the TemplateSpec.  If the parent was linked with a URI, the child deployment will be a combination of the parent and relativePath URIs
     */
    @JvmName("iiijbswwfaagewnr")
    public suspend fun relativePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.relativePath = mapped
    }

    /**
     * @param value The URI of the template to deploy. Use either the uri or id property, but not both.
     */
    @JvmName("khhvoduatqohpfad")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): DeploymentStacksTemplateLinkArgs = DeploymentStacksTemplateLinkArgs(
        contentVersion = contentVersion,
        id = id,
        queryString = queryString,
        relativePath = relativePath,
        uri = uri,
    )
}
